_`umbra.components.addons.projectsExplorer.models`
==================================================

.. automodule:: umbra.components.addons.projectsExplorer.models

Module Attributes
-----------------

.. attribute:: umbra.components.addons.projectsExplorer.models.LOGGER

Classes
-------

.. autoclass:: ProjectsProxyModel
	:show-inheritance:
	:members:

